<?php

namespace App\Http\Controllers;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Validator;

use App\Models\User;

class AuthController extends Controller
{
    public function login(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'email' => 'required|email',
            'password' => 'required',
        ]);

        if ($validator->fails()) {
            return response()->json(['status' => false, 'message' => 'Validation Error', 'data' => null], 400);
        }

        if (Auth::attempt(['email' => $request->email, 'password' => $request->password])) {
            $user = User::where('email', $request->email)->first();

            // Generate a new Sanctum token for the user
            $token = $user->createToken($user->email)->plainTextToken;

            $userData = [
                'id' => $user->id,
                'name' => $user->name,
                'email' => $user->email,
                'phone' => $user->phone,
                'token' => $token,
                'type' =>$user->type,
            ];

            return response()->json(['status' => true, 'message' => 'تم تسجيل الدخول بنجاح', 'data' => $user,'token'=>$token], 200);
        } else {
            return response()->json(['status' => false, 'message' => 'Invalid credentials', 'data' => null], 401);
        }
    }

    public function logout(Request $request)
    {
        // Revoke the current user's Sanctum token
        $request->user()->tokens()->delete();

        return response()->json(['message' => 'تم تسجيل الخروج بنجاح'], 200);
    }

    public function register(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'email' => 'required|email|unique:users',
            'password' => 'required|min:6',
            'phone' => 'required',
        ]);

        if ($validator->fails()) {
            return response()->json(['status' => false, 'message' => 'خطاء في تسجيل الحساب', 'data' => null], 400);
        }
        
        $user = User::create([
            'name' => $request->name,
            'email' => $request->email,
            'password' => bcrypt($request->password),
            'phone' => $request->phone,
            'type' => 3,
        ]);

        // Generate a new Sanctum token for the registered user
        $token = $user->createToken('api-token')->plainTextToken;

      

        return response()->json(['status' => true, 'message' => 'تم تسجيل حسابك بنجاح', 'data' => $user,'token'=>$token], 200);
    }



    public function getallusers(){


        $users = User::get();


        return response(['users' => $users]);



    }

    public function update_premission(Request $request){

        $user = User::find($request->user_id);

        $user->type = $request->type;
        $user->update();


        return response(['users' => $user,'message'=>'تم تحديث الصلاحية بنجاح']);



    }

}
